@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
 from plone.app.layout.viewlets import ViewletBase
-
+from Products.CMFPlone.utils import safe_unicode
 
 class ImageMapViewlet(ViewletBase):
     def update(self):
         self.imagemap = getattr(self.context, "imagemap", "")
 
     def index(self):
-        return self.imagemap or u""
+        return safe_unicode(self.imagemap) or u""
